==> org-lsst-sal-cccamera-2.5.0-sources.jar: org/lsst/sal/cccamera/event/Vacuum_VQMonitor_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Vacuum_VQMonitor_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double vqmpressure_warnHi;

  private final double vqmpressure_warnLo;

  private final double vqmpressure_limitHi;

  private final double vqmpressure_limitLo;

  public Vacuum_VQMonitor_LimitsConfigurationEvent(int priority, String version,
      double vqmpressure_warnHi, double vqmpressure_warnLo, double vqmpressure_limitHi,
      double vqmpressure_limitLo) {
    super (priority);
    this.version = version;
    this.vqmpressure_warnHi = vqmpressure_warnHi;
    this.vqmpressure_warnLo = vqmpressure_warnLo;
    this.vqmpressure_limitHi = vqmpressure_limitHi;
    this.vqmpressure_limitLo = vqmpressure_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getVqmpressure_warnHi() {
    return vqmpressure_warnHi;
  }

  public double getVqmpressure_warnLo() {
    return vqmpressure_warnLo;
  }

  public double getVqmpressure_limitHi() {
    return vqmpressure_limitHi;
  }

  public double getVqmpressure_limitLo() {
    return vqmpressure_limitLo;
  }

  @Override
  public String toString() {
    return "Vacuum_VQMonitor_LimitsConfigurationEvent{" + "version=" + version +
        ", vqmpressure_warnHi=" + vqmpressure_warnHi +", vqmpressure_warnLo=" + vqmpressure_warnLo +
        ", vqmpressure_limitHi=" + vqmpressure_limitHi +
        ", vqmpressure_limitLo=" + vqmpressure_limitLo +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private double vqmpressure_warnHi;

    private double vqmpressure_warnLo;

    private double vqmpressure_limitHi;

    private double vqmpressure_limitLo;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder vqmpressure_warnHi(double vqmpressure_warnHi) {
      this.vqmpressure_warnHi = vqmpressure_warnHi;
      return this;
    }

    public Builder vqmpressure_warnLo(double vqmpressure_warnLo) {
      this.vqmpressure_warnLo = vqmpressure_warnLo;
      return this;
    }

    public Builder vqmpressure_limitHi(double vqmpressure_limitHi) {
      this.vqmpressure_limitHi = vqmpressure_limitHi;
      return this;
    }

    public Builder vqmpressure_limitLo(double vqmpressure_limitLo) {
      this.vqmpressure_limitLo = vqmpressure_limitLo;
      return this;
    }

    public Vacuum_VQMonitor_LimitsConfigurationEvent build() {
      return new Vacuum_VQMonitor_LimitsConfigurationEvent(priority, version, vqmpressure_warnHi, vqmpressure_warnLo, vqmpressure_limitHi, vqmpressure_limitLo);
    }
  }
}

==> org-lsst-sal-cccamera-2.6.3-sources.jar: org/lsst/sal/cccamera/event/Vacuum_VQMonitor_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Vacuum_VQMonitor_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double vqmpressure_warnHi;

  private final double vqmpressure_warnLo;

  private final double vqmpressure_limitHi;

  private final double vqmpressure_limitLo;

  public Vacuum_VQMonitor_LimitsConfigurationEvent(String version, double vqmpressure_warnHi,
      double vqmpressure_warnLo, double vqmpressure_limitHi, double vqmpressure_limitLo) {
    this.version = version;
    this.vqmpressure_warnHi = vqmpressure_warnHi;
    this.vqmpressure_warnLo = vqmpressure_warnLo;
    this.vqmpressure_limitHi = vqmpressure_limitHi;
    this.vqmpressure_limitLo = vqmpressure_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getVqmpressure_warnHi() {
    return vqmpressure_warnHi;
  }

  public double getVqmpressure_warnLo() {
    return vqmpressure_warnLo;
  }

  public double getVqmpressure_limitHi() {
    return vqmpressure_limitHi;
  }

  public double getVqmpressure_limitLo() {
    return vqmpressure_limitLo;
  }

  @Override
  public String toString() {
    return "Vacuum_VQMonitor_LimitsConfigurationEvent{" + "version=" + version +
        ", vqmpressure_warnHi=" + vqmpressure_warnHi +", vqmpressure_warnLo=" + vqmpressure_warnLo +
        ", vqmpressure_limitHi=" + vqmpressure_limitHi +
        ", vqmpressure_limitLo=" + vqmpressure_limitLo +"}";
  }
}
